@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: lrucache
 version: 1.2.0.0
-id: lrucache-1.2.0.0-fe7339ef35e8dfe001bb854bdca651f6
-key: lruca_EjcPCQPwipkFLS5aHjRn10
+id: lrucache-1.2.0.0-f6a00c6545b50474cbf44906f698e532
+key: lruca_11NWx4YeVsv5A6RrohkVPO
 license: BSD3
 copyright: Carl Howells, 2010-2015
 maintainer: chowells79@gmail.com
@@ -26,11 +26,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/lrucache-1.2.0.0
-hs-libraries: HSlrucache-1.2.0.0-EjcPCQPwipkFLS5aHjRn10
+hs-libraries: HSlrucache-1.2.0.0-11NWx4YeVsv5A6RrohkVPO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
+    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
 haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
 haddock-html: /usr/share/doc/haskell-lrucache/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
